@@ -18,6 +18,7 @@ which can be combined with the CWL V1.0 schema as shown below::
 
   # g++ versions older than version 10 may need "--std=c++2a" instead of "--std=c++20"
 """
+
 import re
 from typing import IO, Any, Dict, List, Optional, Tuple, Union, cast
 
@@ -940,7 +941,7 @@ public:
                         break
 
                 if not found:
-                    self.classDefinitions[key].fields.append(field)
+                    self.classDefinitions[key].fields.append(field)  # noqa: B038
 
         # write definitions
         for key in self.enumDefinitions:
